.. code-block:: bash

   Usage: nessie [OPTIONS] COMMAND [ARGS]...

     Nessie cli tool.

     Interact with Nessie branches and tables via the command line

   Options:
     --json             write output in json format.
     -v, --verbose      Verbose output.
     --endpoint TEXT    Optional endpoint, if different from config file.
     --auth-token TEXT  Optional bearer auth token, if different from config file.
     --version
     --help             Show this message and exit.

   Commands:
     branch       Branch operations.
     cherry-pick  Cherry-pick HASHES onto another branch.
     config       Set and view config.
     content      View, list content, and commit changes.
     diff         Show diff between two given references.
     log          Show commit log.
     merge        Merge FROM_REF into another branch.
     reflog       Show reflog.
     remote       Set and view remote endpoint.
     tag          Tag operations.


